@@ -762,6 +762,13 @@ impl Screen for SwarmPanel {
         }
         None
     }
+
+    fn footer_spans(&self) -> Vec<String> {
+        vec![
+            format!(" {} ", UiKey::CYCLE_VIEW.to_string()),
+            " Next tab ".to_string(),
+        ]
+    }
 }
 
 impl SplitPanel for SwarmPanel {
